All of lore.kernel.org
 help / color / mirror / Atom feed
From: Richard Henderson <richard.henderson@linaro.org>
To: qemu-devel@nongnu.org
Subject: [PATCH v2 11/23] target/microblaze: Check CF_NO_GOTO_TB for DISAS_JUMP
Date: Tue, 12 Oct 2021 09:21:47 -0700	[thread overview]
Message-ID: <20211012162159.471406-12-richard.henderson@linaro.org> (raw)
In-Reply-To: <20211012162159.471406-1-richard.henderson@linaro.org>

We were using singlestep_enabled as a proxy for whether
translator_use_goto_tb would always return false.

Signed-off-by: Richard Henderson <richard.henderson@linaro.org>
---
 target/microblaze/translate.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/target/microblaze/translate.c b/target/microblaze/translate.c
index a14ffed784..7e465b629a 100644
--- a/target/microblaze/translate.c
+++ b/target/microblaze/translate.c
@@ -1779,7 +1779,7 @@ static void mb_tr_tb_stop(DisasContextBase *dcb, CPUState *cs)
         break;
 
     case DISAS_JUMP:
-        if (dc->jmp_dest != -1 && !cs->singlestep_enabled) {
+        if (dc->jmp_dest != -1 && !(tb_cflags(dc->base.tb) & CF_NO_GOTO_TB)) {
             /* Direct jump. */
             tcg_gen_discard_i32(cpu_btarget);
 
@@ -1804,7 +1804,7 @@ static void mb_tr_tb_stop(DisasContextBase *dcb, CPUState *cs)
             return;
         }
 
         /* Indirect jump (or direct jump w/ singlestep) */
         tcg_gen_mov_i32(cpu_pc, cpu_btarget);
         tcg_gen_discard_i32(cpu_btarget);
 
@@ -1804,7 +1804,7 @@ static void mb_tr_tb_stop(DisasContextBase *dcb, CPUState *cs)
         }
 
-        /* Indirect jump (or direct jump w/ singlestep) */
+        /* Indirect jump (or direct jump w/ goto_tb disabled) */
         tcg_gen_mov_i32(cpu_pc, cpu_btarget);
         tcg_gen_discard_i32(cpu_btarget);
-- 
2.25.1



  parent reply	other threads:[~2021-10-12 16:33 UTC|newest]

Thread overview: 32+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-10-12 16:21 [PATCH v2 00/23] tcg: singlestep reorg Richard Henderson
2021-10-12 16:21 ` [PATCH v2 01/23] accel/tcg: Handle gdb singlestep in cpu_tb_exec Richard Henderson
2021-10-12 16:21 ` [PATCH v2 02/23] target/alpha: Drop checks for singlestep_enabled Richard Henderson
2021-10-12 22:32   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 03/23] target/avr: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 04/23] target/cris: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 05/23] target/hexagon: " Richard Henderson
2021-10-12 22:30   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 06/23] target/arm: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 07/23] target/hppa: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 08/23] target/i386: Check CF_NO_GOTO_TB for dc->jmp_opt Richard Henderson
2021-10-12 16:21 ` [PATCH v2 09/23] target/i386: Drop check for singlestep_enabled Richard Henderson
2021-10-12 16:21 ` [PATCH v2 10/23] target/m68k: Drop checks " Richard Henderson
2021-10-12 16:21 ` Richard Henderson [this message]
2021-10-12 16:21 ` [PATCH v2 12/23] target/microblaze: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 13/23] target/mips: Fix single stepping Richard Henderson
2021-10-12 22:26   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 14/23] target/mips: Drop exit checks for singlestep_enabled Richard Henderson
2021-10-12 16:21 ` [PATCH v2 15/23] target/openrisc: Drop " Richard Henderson
2021-10-12 22:32   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 16/23] target/ppc: Drop exit " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 17/23] target/riscv: Remove dead code after exception Richard Henderson
2021-10-12 21:35   ` Alistair Francis
2021-10-12 16:21 ` [PATCH v2 18/23] target/riscv: Remove exit_tb and lookup_and_goto_ptr Richard Henderson
2021-10-12 21:34   ` Alistair Francis
2021-10-12 16:21 ` [PATCH v2 19/23] target/rx: Drop checks for singlestep_enabled Richard Henderson
2021-10-12 22:28   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 20/23] target/s390x: Drop check " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 21/23] target/sh4: " Richard Henderson
2021-10-12 16:21 ` [PATCH v2 22/23] target/tricore: " Richard Henderson
2021-10-12 22:29   ` Philippe Mathieu-Daudé
2021-10-12 16:21 ` [PATCH v2 23/23] target/xtensa: " Richard Henderson

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211012162159.471406-12-richard.henderson@linaro.org \
    --to=richard.henderson@linaro.org \
    --cc=qemu-devel@nongnu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.